SHA256
1
0
forked from pool/sslscan
sslscan/02-sslscan-spelling-mistake.diff

35 lines
1.3 KiB
Diff
Raw Normal View History

# 02-sslscan-spelling-mistake.diff
# Author: Marvin Stark <marv@der-marv.de>
# DP: Fix spelling errors
Index: sslscan/sslscan.c
===================================================================
--- sslscan.orig/sslscan.c 2010-01-25 19:26:03.000000000 +0100
+++ sslscan/sslscan.c 2010-01-25 19:26:27.000000000 +0100
@@ -644,7 +644,7 @@
}
// Test for prefered ciphers
int defaultCipher(struct sslCheckOptions *options, SSL_METHOD *sslMethod)
{
// Variables...
@@ -1185,7 +1185,7 @@
if (status == true)
{
// Test prefered ciphers...
printf("\n %sPrefered Server Cipher(s):%s\n", COL_BLUE, RESET);
if (options->pout == true)
printf("|| Version || Bits || Cipher ||\n");
@@ -1367,7 +1367,7 @@
printf("%s%s%s\n", COL_BLUE, program_banner, RESET);
printf("SSLScan is a fast SSL port scanner. SSLScan connects to SSL\n");
printf("ports and determines what ciphers are supported, which are\n");
- printf("the servers prefered ciphers, which SSL protocols are\n");
+ printf("the servers preferred ciphers, which SSL protocols are\n");
printf("supported and returns the SSL certificate. Client\n");
printf("certificates / private key can be configured and output is\n");
printf("to text / XML.\n\n");
@@ -644,7 +644,7 @@
}
-// Test for prefered ciphers
+// Test for preferred ciphers
int defaultCipher(struct sslCheckOptions *options, SSL_METHOD *sslMethod)
{
@@ -1185,7 +1185,7 @@
if (status == true)
{
- // Test prefered ciphers...
+ // Test preferred ciphers...
printf("\n %sPrefered Server Cipher(s):%s\n", COL_BLUE, RESET);
if (options->pout == true)